/****************************************************************************
** Meta object code from reading C++ file 'htmlgeneratorwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/widgets/htmlgeneratorwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'htmlgeneratorwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19HtmlGeneratorWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto HtmlGeneratorWidget::qt_create_metaobjectdata<qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HtmlGeneratorWidget",
        "producerChanged",
        "",
        "Mlt::Producer*",
        "on_colorButton_clicked",
        "on_preset_selected",
        "p",
        "on_preset_saveClicked",
        "on_imageButton_clicked",
        "on_pushButton_clicked",
        "on_videoButton_clicked",
        "on_cssToggleButton_toggled",
        "checked",
        "on_bodyToggleButton_toggled",
        "on_javascriptToggleButton_toggled",
        "on_bodyTextEdit_textChanged",
        "on_presetIconView_itemClicked",
        "QListWidgetItem*",
        "item"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'producerChanged'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'on_colorButton_clicked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_preset_selected'
        QtMocHelpers::SlotData<void(void *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::VoidStar, 6 },
        }}),
        // Slot 'on_preset_saveClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_imageButton_clicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_clicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_videoButton_clicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_cssToggleButton_toggled'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'on_bodyToggleButton_toggled'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'on_javascriptToggleButton_toggled'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'on_bodyTextEdit_textChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_presetIconView_itemClicked'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HtmlGeneratorWidget, qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HtmlGeneratorWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>.metaTypes,
    nullptr
} };

void HtmlGeneratorWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HtmlGeneratorWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->producerChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 1: _t->on_colorButton_clicked(); break;
        case 2: _t->on_preset_selected((*reinterpret_cast<std::add_pointer_t<void*>>(_a[1]))); break;
        case 3: _t->on_preset_saveClicked(); break;
        case 4: _t->on_imageButton_clicked(); break;
        case 5: _t->on_pushButton_clicked(); break;
        case 6: _t->on_videoButton_clicked(); break;
        case 7: _t->on_cssToggleButton_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->on_bodyToggleButton_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->on_javascriptToggleButton_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->on_bodyTextEdit_textChanged(); break;
        case 11: _t->on_presetIconView_itemClicked((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HtmlGeneratorWidget::*)(Mlt::Producer * )>(_a, &HtmlGeneratorWidget::producerChanged, 0))
            return;
    }
}

const QMetaObject *HtmlGeneratorWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HtmlGeneratorWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19HtmlGeneratorWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractProducerWidget"))
        return static_cast< AbstractProducerWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int HtmlGeneratorWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void HtmlGeneratorWidget::producerChanged(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
